asr.test.test\_setup\_materials
===============================

.. automodule:: asr.test.test_setup_materials

   
   
   .. rubric:: Functions

   
   .. autofunction:: test_setup_magnetize
   
   

   
   
   

   
   
   